///////////////////////////////////////////////////////////////////////////////
//
//    (C) Copyright 1995 - 2013 OSR Open Systems Resources, Inc.
//    All Rights Reserved
//
//    This sofware is supplied for instructional purposes only.
//
//    OSR Open Systems Resources, Inc. (OSR) expressly disclaims any warranty
//    for this software.  THIS SOFTWARE IS PROVIDED  "AS IS" WITHOUT WARRANTY
//    OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION,
//    THE IMPLIED WARRANTIES OF MECHANTABILITY OR FITNESS FOR A PARTICULAR
//    PURPOSE.  THE ENTIRE RISK ARISING FROM THE USE OF THIS SOFTWARE REMAINS
//    WITH YOU.  OSR's entire liability and your exclusive remedy shall not
//    exceed the price paid for this material.  In no event shall OSR or its
//    suppliers be liable for any damages whatsoever (including, without
//    limitation, damages for loss of business profit, business interruption,
//    loss of business information, or any other pecuniary loss) arising out
//    of the use or inability to use this software, even if OSR has been
//    advised of the possibility of such damages.  Because some states/
//    jurisdictions do not allow the exclusion or limitation of liability for
//    consequential or incidental damages, the above limitation may not apply
//    to you.
//
//    OSR Open Systems Resources, Inc.
//    105 Route 101A Suite 19
//    Amherst, NH 03031  (603) 595-6500 FAX: (603) 595-6503
//    email bugs to: bugs@osr.com
//
//
//    MODULE:
//
//        PDBFIX.C
//
//    ABSTRACT:
//
//      This is a dummy file that exists solely to provide type
//      information that is missing from public Microsoft PDBs.
//      It is only ever compiled (not linked) and the resulting
//      type information is copied into the MS provided public
//      PDB
//
//    AUTHOR(S):
//
//        OSR Open Systems Resources, Inc.
// 
//    REVISION:   
//
//
///////////////////////////////////////////////////////////////////////////////
#include <ntddk.h>

// 
// Windows 8 PDBs provide type information for nt!_ENODE, which
// causes the !exqueue extension to fail while trying to query
// the type of the KeNumberNodes global.
// 
// Note that this is an annoying problem as it's not the type
// itself that is missing (appears to simply be an ULONG). In
// this case, it's the fact that globals are disassociated with
// their type information. Thus, even if we could add the type
// for this global we wouldn't be able to fix the problem by
// simply adding the type to the PDB.
// 
// We fix the problem in this case by performing a hack and
// creating a data type with the same name as the global and
// making it the appropriate size. This manages to trick the
// debugger engine into getting a size for the global due to the
// aliasing issue that it causes. Feel free to wash your hands
// after having read that...
// 
#include <pshpack1.h>
struct KeNumberNodes {
    // 
    // Add a dummy member to get the size right.
    // 
    USHORT Dummy;
};
#include <poppack.h>

// 
// Unused types are NOT in the PDB! So, make a dummy variable to
// get the type in the PDB.
// 
struct KeNumberNodes KeNumberNodesDummy;
    
